<!---
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/
 
Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.
 
The Original Code is comprised of the ADF directory
 
The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2011.
All Rights Reserved.
 
By downloading, modifying, distributing, using and/or accessing any files
in this directory, you agree to the terms and conditions of the applicable
end user license agreement.
--->

<!---
/* *************************************************************** */
Author: 	
	PaperThin, Inc.
	M. Carroll
Name:
	photo_directory_render.cfc
Summary:
	Custom field for the photo directory field related to the title field.
ADF App:
	pt_photo_gallery
Version:
	2.1
History:
	2011-02-08 - MFC - Created
	2012-01-20 - MFC - Added code Simple Forms.
	2015-07-08 - DJM - Converted to CFC
	2016-02-26 - DRM - Resource detection support
--->
<cfcomponent displayName="PhotoDirectory Render" extends="ADF.extensions.customfields.adf-form-field-renderer-base">

<cffunction name="renderControl" returntype="void" access="public">
	<cfargument name="fieldName" type="string" required="yes">
	<cfargument name="fieldDomID" type="string" required="yes">
	<cfargument name="value" type="string" required="yes">
	
	<cfscript>
		var inputParameters = Duplicate(arguments.parameters);
		var currentValue = arguments.value;	// the field's current value
		var allowFieldEdit = true;
		var readOnly = (arguments.displayMode EQ 'readonly') ? true : false;
		
		inputParameters = setDefaultParameters(argumentCollection=arguments);
		
		// Determine if we have a value to make the field editable
		if ( LEN(currentValue) OR currentValue != '' )
			allowFieldEdit = false;
		
		if (allowFieldEdit)
			renderJSFunctions(argumentCollection=arguments,fieldParameters=inputParameters);
	</cfscript>
	<cfoutput>
		<cfif allowFieldEdit>
			<input type="text" name="#arguments.fieldName#" value="#currentValue#" id="#inputParameters.fldID#" size="#inputParameters.fldSize#"<cfif LEN(TRIM(inputParameters.fldClass))> class="#inputParameters.fldClass#"</cfif> tabindex="#arguments.renderTabIndex#" <cfif readOnly>readonly="true"</cfif>>
		<cfelse>
			#currentValue#
			<!--- // Pass the data through but don't update it --->
			<input type="hidden" name="#arguments.fieldName#" value="#currentValue#" id="#inputParameters.fldID#"<cfif LEN(TRIM(inputParameters.fldClass))> class="#inputParameters.fldClass#"</cfif>>
		</cfif>
	</cfoutput>
</cffunction>

<cffunction name="renderJSFunctions" returntype="void" access="private">
	<cfargument name="fieldName" type="string" required="yes">
	<cfargument name="fieldDomID" type="string" required="yes">
	<cfargument name="value" type="string" required="yes">
	<cfargument name="fieldParameters" type="struct" required="yes">
	
	<cfscript>
		var inputParameters = Duplicate(arguments.fieldParameters);
	
		var currentValue = arguments.value;	// the field's current value
		var allowFieldEdit = true;
		
		// Determine if we have a value to make the field editable
		if ( LEN(currentValue) OR currentValue != '' )
			allowFieldEdit = false;
	</cfscript>
<cfoutput>
<!--- // Don't render the javascript if Allow Field Edit is False. The data is locked and
		 we don't want to mess with it. --->
<cfif allowFieldEdit>
<script type="text/javascript">
<!--
// Load JQuery
jQuery(document).ready(function() {
	// Bind an off focus event to the title field.
	jQuery("input###inputParameters.titleFldID#").focusout(function() {
		// Get the value for the title
		cleanedTitleText = #arguments.fieldName#_cleanText(jQuery("input###inputParameters.titleFldID#").val())
		jQuery("input###inputParameters.fldID#").val(cleanedTitleText);
	});
	
	// Bind off focus this directory field also, just to clean the text
	jQuery("input###inputParameters.fldID#").focusout(function() {
		// Get the value for the title
		cleanedTitleText = #arguments.fieldName#_cleanText(jQuery("input###inputParameters.fldID#").val())
		jQuery("input###inputParameters.fldID#").val(cleanedTitleText);
	});
});

// Remove all special characters
function #arguments.fieldName#_cleanText(inString){
	return inString.replace(/[^a-zA-Z0-9]+/g,'').toLowerCase();
}
//-->
</script>
</cfif>
</cfoutput>
</cffunction>

<cffunction name="setDefaultParameters" returntype="struct" access="private">
	<cfargument name="fieldName" type="string" required="yes">
	<cfargument name="fieldDomID" type="string" required="yes">
	<cfargument name="value" type="string" required="yes">
	
	<cfscript>
		var inputParameters = Duplicate(arguments.parameters);
		
		if ( NOT StructKeyExists(inputParameters, "titleFldID") )
			inputParameters.titleFldID = "";	
		if ( NOT StructKeyExists(inputParameters, "fldID") )
			inputParameters.fldID = arguments.fieldName;
		if ( NOT StructKeyExists(inputParameters, "fldClass") )
			inputParameters.fldClass = "";
		if ( not structKeyExists(inputParameters, "fldSize") )
			inputParameters.fldSize = "40";
		
		return inputParameters;
	</cfscript>
</cffunction>

<cfscript>
	private any function getValidationJS(required string formName, required string fieldName, required boolean isRequired)
	{
		if (arguments.isRequired)
			return 'hasValue(document.#arguments.formName#.#arguments.fieldName#, "TEXT")';
		return "";
	}
	
	private string function getValidationMsg()
	{
		return "Please select a value for the #arguments.label# field.";
	}

	public string function getResourceDependencies()
	{
		return listAppend(super.getResourceDependencies(), "jQuery");
	}
	public string function loadResourceDependencies()
	{
		application.ptPhotoGallery.scripts.loadJQuery();
	}
</cfscript>

</cfcomponent>